@@ -338,16 +338,28 @@ class DFM(BaseFactorModel):
         
         # Ensure data is on same device as model (Lightning handles this automatically)
         X = X.to(self.device)
-        self.data_processed = X
         
         device = X.device
         dtype = X.dtype
         
-        # Initialize parameters
+        # CRITICAL: Impute missing data BEFORE EM loop
+        # Initialize parameters (this performs imputation internally)
         self.initialize_from_data(X)
         
-        # Prepare data for EM
-        y = X.T  # (N x T)
+        # After initialization, get the imputed data for EM loop
+        # initialize_from_data uses rem_nans_spline_torch internally, but we need
+        # to apply the same imputation to the data used in EM loop
+        from dfm_python.utils.data import rem_nans_spline_torch
+        opt_nan = {'method': self.nan_method, 'k': self.nan_k}
+        X_imputed, _ = rem_nans_spline_torch(X, method=opt_nan.get('method', 2), k=opt_nan.get('k', 3))
+        # Remove any remaining NaN/inf
+        X_imputed = torch.where(torch.isfinite(X_imputed), X_imputed, torch.tensor(0.0, device=device, dtype=dtype))
+        
+        # Store imputed data
+        self.data_processed = X_imputed
+        
+        # Prepare data for EM (use imputed data, not raw data)
+        y = X_imputed.T  # (N x T)
         
         # Initialize state
         previous_loglik = float('-inf')
@@ -382,6 +394,25 @@ class DFM(BaseFactorModel):
             # Perform EM step - use self.em(...) instead of em_step(...)
             C_new, R_new, A_new, Q_new, Z_0_new, V_0_new, loglik = self.em(em_params)
             
+            # Check for NaN in updated parameters (early stopping for numerical instability)
+            nan_detected = False
+            if torch.any(torch.isnan(C_new)) or torch.any(torch.isnan(A_new)) or \
+               torch.any(torch.isnan(Q_new)) or torch.any(torch.isnan(R_new)) or \
+               torch.any(torch.isnan(Z_0_new)) or torch.any(torch.isnan(V_0_new)) or \
+               (isinstance(loglik, float) and (np.isnan(loglik) or np.isinf(loglik))):
+                nan_detected = True
+                _logger.error(
+                    f"EM algorithm: NaN/Inf detected in parameters at iteration {num_iter + 1}. "
+                    f"Stopping early to prevent further numerical instability. "
+                    f"C NaN: {torch.any(torch.isnan(C_new)).item()}, "
+                    f"A NaN: {torch.any(torch.isnan(A_new)).item()}, "
+                    f"Q NaN: {torch.any(torch.isnan(Q_new)).item()}, "
+                    f"R NaN: {torch.any(torch.isnan(R_new)).item()}, "
+                    f"loglik: {loglik}"
+                )
+                # Don't update parameters if NaN detected - keep previous values
+                break
+            
             # Update parameters
             with torch.no_grad():
                 self.A.data = A_new
@@ -411,7 +442,9 @@ class DFM(BaseFactorModel):
             self.log('train/em_iteration', float(num_iter), on_step=False, on_epoch=True)
             self.log('train/loglik_change', change, on_step=False, on_epoch=True)
             
-            if num_iter % 10 == 0:
+            # Log progress more frequently for visibility
+            if num_iter % 5 == 0 or num_iter == 1:
+                print(f"[EM {num_iter:4d}/{self.max_iter:4d}] Log-likelihood: {loglik:12.6f} | Change: {change:10.6e} {'✓' if converged else ''}")
                 _logger.info(
                     f"EM iteration {num_iter}/{self.max_iter}: "
                     f"loglik={loglik:.4f}, change={change:.2e}"
@@ -430,6 +463,13 @@ class DFM(BaseFactorModel):
             converged=converged
         )
         
+        # Final status message
+        if converged:
+            print(f"\n✓ EM algorithm converged after {num_iter} iterations (loglik: {loglik:.6f})")
+        else:
+            print(f"\n⚠ EM algorithm stopped after {num_iter} iterations (loglik: {loglik:.6f}, change: {change:.2e})")
+        _logger.info(f"EM training completed: converged={converged}, iterations={num_iter}, final_loglik={loglik:.6f}")
+        
         return self.training_state
     
     def get_result(self) -> DFMResult:
